@@ -3,7 +3,7 @@ context("HMMs with multivariate responses")
 ## Simulate data from a Markov model 
 nsubj <- 30; nobspt <- 5
 sim.df <- data.frame(subject = rep(1:nsubj, each=nobspt),
-                     time = seq(0, 20, length=nobspt))
+                     time = seq(0, 20, length.out=nobspt))
 suppressWarnings(RNGversion("3.5.0"))
 set.seed(1)
 two.q <- rbind(c(-0.1, 0.1), c(0, 0))
@@ -38,7 +38,8 @@ test_that("HMMs with multiple responses from the same distribution",{
                hmodel = list(hmmBinom(size=40, prob=0.2),
                hmmBinom(size=40, prob=0.2)), fixedpars=TRUE)
     expect_equal(hmm$minus2loglik, 4387.58552977954, tol=1e-06)
-    expect_lt(deriv_error(hmm), err)    
+    expect_lt(deriv_error(hmm), err)
+    print(hmmBinom(size=40, prob=0.2))
 })
 
 test_that("HMMs with multiple responses: cbind() in formula",{
@@ -64,6 +65,8 @@ test_that("HMMs with multiple responses from different distributions",{
                                          hmmBinom(size=40, prob=0.3))),
                      fixedpars=TRUE),
                  "Only one column in state outcome data")
+    print(hmmMV(hmmBinom(size=40, prob=0.3),
+                hmmBinom(size=40, prob=0.3)))
 })
 
 test_that("HMMs with multiple responses from different distributions: non-default initprobs, different probs",{
@@ -113,7 +116,6 @@ three.q <- rbind(cbind(two.q, c(0.1,0.1)), c(0,0,0))
 options(msm.test.analytic.derivatives=NULL)
 
 test_that("HMMs with multiple responses: exact death and hmmIdent",{
-
     hmm <- msm(dobs ~ time, subject=subject, data=datd, qmatrix=three.q,
                death = 3,
                hmodel = list(hmmMV(hmmBinom(size=40, prob=0.3),
@@ -135,3 +137,14 @@ test_that("HMMs with multiple responses: exact death and hmmIdent",{
 })
 
 ## censoring? 
+
+
+
+test_that("hmm errors",{
+  expect_error(msm(obs ~ time, subject=subject, data=dat, qmatrix=two.q,
+                   hmodel = "wrong"), "should be a list")
+  expect_error(msm(obs ~ time, subject=subject, data=dat, qmatrix=two.q,
+                   hmodel = list(hmmBinom(size=40, prob=0.2),
+                                 hmmBinom(size=40, prob=0.2)), hcovariates="Wrong", fixedpars=TRUE),
+               "should be a list")
+})
